@@ -26,8 +26,6 @@
 import logging
 import logging.handlers
 import os
-import time
-import signal
 
 import pyinotify
 
@@ -47,7 +45,7 @@ class MoveItBase(object):
         self.running = False
         self.notifier = None
         self.watchman = None
-        self.sync_pub = None
+        self.sync_publisher = None
         self._np = None
         self.chains = {}
         setup_logging(cmd_args, chain_type)
@@ -58,12 +56,12 @@ class MoveItBase(object):
         """Reload configuration file."""
         if self.chain_type == "client":
             from trollmoves.client import reload_config
-            reload_config(filename, self.chains, *args, sync_pub_instance=self.sync_pub,
+            reload_config(filename, self.chains, *args, sync_publisher=self.sync_publisher,
                           **kwargs)
         else:
             # Also Mirror uses the reload_config from the Server
             from trollmoves.server import reload_config
-            reload_config(filename, self.chains, *args, publisher=self.sync_pub,
+            reload_config(filename, self.chains, *args, publisher=self.sync_publisher,
                           use_watchdog=self.cmd_args.watchdog,
                           disable_backlog=self.cmd_args.disable_backlog)
 
@@ -73,11 +71,11 @@ class MoveItBase(object):
         if self.chain_type == "client":
             from trollmoves.client import reload_config
             reload_config(self.cmd_args.config_file, self.chains,
-                          sync_pub_instance=self.sync_pub)
+                          sync_publisher=self.sync_publisher)
         else:
             from trollmoves.server import reload_config
             reload_config(self.cmd_args.config_file, self.chains,
-                          publisher=self.sync_pub,
+                          publisher=self.sync_publisher,
                           use_watchdog=self.cmd_args.watchdog,
                           disable_backlog=self.cmd_args.disable_backlog)
 
